@@ -1020,7 +1020,7 @@ QString TorrentDownload::message() const
 		case libtorrent::torrent_status::seeding:
 		case libtorrent::torrent_status::downloading:
 		case libtorrent::torrent_status::finished:
-			state += QString("Seeds: %1 (%2) | Peers: %3 (%4)");
+			state += tr("Seeders: %1 (%2) | Leechers: %3 (%4)");
 			
 			if(m_status.state == libtorrent::torrent_status::downloading)
 				state = state.arg(m_status.num_seeds);
@@ -1049,6 +1049,11 @@ QString TorrentDownload::message() const
 			break;
 		}
 	}
+	else
+	{
+		if(m_status.num_complete >= 0 || m_status.num_incomplete >= 0)
+		   state = tr("Seeders: %1 | Leechers: %2").arg(m_status.num_complete).arg(m_status.num_incomplete);
+	}
 	
 	return state;
 }
